@@ -1,3 +1,5 @@
+#define QT_FEATURE_version_tagging 1
+
 #define QT_FEATURE_shared 1
 
 #define QT_FEATURE_static -1
@@ -20,11 +22,9 @@
 
 #define QT_FEATURE_framework -1
 
-#define QT_FEATURE_cxx20 -1
+#define QT_FEATURE_cxx20 1
 
-#define QT_FEATURE_cxx2a -1
-
-#define QT_FEATURE_cxx2b -1
+#define QT_FEATURE_cxx2a 1
 
 #define QT_FEATURE_cxx2b -1
 
@@ -53,13 +53,15 @@
 #define QT_FEATURE_opensslv30 1
 
 
-#define QT_VERSION_STR "6.6.2"
+#define QT_VERSION_STR "6.8.2"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 6
+#define QT_VERSION_MINOR 8
 
 #define QT_VERSION_PATCH 2
+
+#define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
 #define QT_COMPILER_SUPPORTS_SSE2 1
